/**
  * Art
**/
.target {
  /* Default Size */
  _test: "@include art(xxxxxxx xxxxxxxxxx   xxxxxx       xxxxxxn                                        nxxxxxxx xxxxxxxxxxxx xxxxxxx     xxxxxxxn                                        n  xxx     xxx    xxx   xxxxxx    xxxxx  n                                        n  xxx     xxxxxxxxx    xxxxxxx xxxxxxx  n                                        n  xxx     xxxxxxxxx    xxx xxxxxxx xxx  n                                        n  xxx     xxx    xxx   xxx  xxxxx  xxx  n                                        nxxxxxxx xxxxxxxxxxxx xxxxx   xxx   xxxxxn                                        nxxxxxxx xxxxxxxxxx   xxxxx    x    xxxxx)";
  height: 1px;
  width: 1px;
  border-radius: 0%;
  box-shadow: 1px 1px 0 black, 2px 1px 0 black, 3px 1px 0 black, 4px 1px 0 black, 5px 1px 0 black, 6px 1px 0 black, 7px 1px 0 black, 9px 1px 0 black, 10px 1px 0 black, 11px 1px 0 black, 12px 1px 0 black, 13px 1px 0 black, 14px 1px 0 black, 15px 1px 0 black, 16px 1px 0 black, 17px 1px 0 black, 18px 1px 0 black, 22px 1px 0 black, 23px 1px 0 black, 24px 1px 0 black, 25px 1px 0 black, 26px 1px 0 black, 27px 1px 0 black, 35px 1px 0 black, 36px 1px 0 black, 37px 1px 0 black, 38px 1px 0 black, 39px 1px 0 black, 40px 1px 0 black, 1px 3px 0 black, 2px 3px 0 black, 3px 3px 0 black, 4px 3px 0 black, 5px 3px 0 black, 6px 3px 0 black, 7px 3px 0 black, 9px 3px 0 black, 10px 3px 0 black, 11px 3px 0 black, 12px 3px 0 black, 13px 3px 0 black, 14px 3px 0 black, 15px 3px 0 black, 16px 3px 0 black, 17px 3px 0 black, 18px 3px 0 black, 19px 3px 0 black, 20px 3px 0 black, 22px 3px 0 black, 23px 3px 0 black, 24px 3px 0 black, 25px 3px 0 black, 26px 3px 0 black, 27px 3px 0 black, 28px 3px 0 black, 34px 3px 0 black, 35px 3px 0 black, 36px 3px 0 black, 37px 3px 0 black, 38px 3px 0 black, 39px 3px 0 black, 40px 3px 0 black, 3px 5px 0 black, 4px 5px 0 black, 5px 5px 0 black, 11px 5px 0 black, 12px 5px 0 black, 13px 5px 0 black, 18px 5px 0 black, 19px 5px 0 black, 20px 5px 0 black, 24px 5px 0 black, 25px 5px 0 black, 26px 5px 0 black, 27px 5px 0 black, 28px 5px 0 black, 29px 5px 0 black, 34px 5px 0 black, 35px 5px 0 black, 36px 5px 0 black, 37px 5px 0 black, 38px 5px 0 black, 3px 7px 0 black, 4px 7px 0 black, 5px 7px 0 black, 11px 7px 0 black, 12px 7px 0 black, 13px 7px 0 black, 14px 7px 0 black, 15px 7px 0 black, 16px 7px 0 black, 17px 7px 0 black, 18px 7px 0 black, 19px 7px 0 black, 24px 7px 0 black, 25px 7px 0 black, 26px 7px 0 black, 27px 7px 0 black, 28px 7px 0 black, 29px 7px 0 black, 30px 7px 0 black, 32px 7px 0 black, 33px 7px 0 black, 34px 7px 0 black, 35px 7px 0 black, 36px 7px 0 black, 37px 7px 0 black, 38px 7px 0 black, 3px 9px 0 black, 4px 9px 0 black, 5px 9px 0 black, 11px 9px 0 black, 12px 9px 0 black, 13px 9px 0 black, 14px 9px 0 black, 15px 9px 0 black, 16px 9px 0 black, 17px 9px 0 black, 18px 9px 0 black, 19px 9px 0 black, 24px 9px 0 black, 25px 9px 0 black, 26px 9px 0 black, 28px 9px 0 black, 29px 9px 0 black, 30px 9px 0 black, 31px 9px 0 black, 32px 9px 0 black, 33px 9px 0 black, 34px 9px 0 black, 36px 9px 0 black, 37px 9px 0 black, 38px 9px 0 black, 3px 11px 0 black, 4px 11px 0 black, 5px 11px 0 black, 11px 11px 0 black, 12px 11px 0 black, 13px 11px 0 black, 18px 11px 0 black, 19px 11px 0 black, 20px 11px 0 black, 24px 11px 0 black, 25px 11px 0 black, 26px 11px 0 black, 29px 11px 0 black, 30px 11px 0 black, 31px 11px 0 black, 32px 11px 0 black, 33px 11px 0 black, 36px 11px 0 black, 37px 11px 0 black, 38px 11px 0 black, 1px 13px 0 black, 2px 13px 0 black, 3px 13px 0 black, 4px 13px 0 black, 5px 13px 0 black, 6px 13px 0 black, 7px 13px 0 black, 9px 13px 0 black, 10px 13px 0 black, 11px 13px 0 black, 12px 13px 0 black, 13px 13px 0 black, 14px 13px 0 black, 15px 13px 0 black, 16px 13px 0 black, 17px 13px 0 black, 18px 13px 0 black, 19px 13px 0 black, 20px 13px 0 black, 22px 13px 0 black, 23px 13px 0 black, 24px 13px 0 black, 25px 13px 0 black, 26px 13px 0 black, 30px 13px 0 black, 31px 13px 0 black, 32px 13px 0 black, 36px 13px 0 black, 37px 13px 0 black, 38px 13px 0 black, 39px 13px 0 black, 40px 13px 0 black, 1px 15px 0 black, 2px 15px 0 black, 3px 15px 0 black, 4px 15px 0 black, 5px 15px 0 black, 6px 15px 0 black, 7px 15px 0 black, 9px 15px 0 black, 10px 15px 0 black, 11px 15px 0 black, 12px 15px 0 black, 13px 15px 0 black, 14px 15px 0 black, 15px 15px 0 black, 16px 15px 0 black, 17px 15px 0 black, 18px 15px 0 black, 22px 15px 0 black, 23px 15px 0 black, 24px 15px 0 black, 25px 15px 0 black, 26px 15px 0 black, 31px 15px 0 black, 36px 15px 0 black, 37px 15px 0 black, 38px 15px 0 black, 39px 15px 0 black, 40px 15px 0 black;
  /* Changed Size */
  _test: "@include art(xxxxxxx xxxxxxxxxx   xxxxxx       xxxxxxn                                        nxxxxxxx xxxxxxxxxxxx xxxxxxx     xxxxxxxn                                        n  xxx     xxx    xxx   xxxxxx    xxxxx  n                                        n  xxx     xxxxxxxxx    xxxxxxx xxxxxxx  n                                        n  xxx     xxxxxxxxx    xxx xxxxxxx xxx  n                                        n  xxx     xxx    xxx   xxx  xxxxx  xxx  n                                        nxxxxxxx xxxxxxxxxxxx xxxxx   xxx   xxxxxn                                        nxxxxxxx xxxxxxxxxx   xxxxx    x    xxxxx, 5px)";
  height: 5px;
  width: 5px;
  border-radius: 0%;
  box-shadow: 5px 5px 0 black, 10px 5px 0 black, 15px 5px 0 black, 20px 5px 0 black, 25px 5px 0 black, 30px 5px 0 black, 35px 5px 0 black, 45px 5px 0 black, 50px 5px 0 black, 55px 5px 0 black, 60px 5px 0 black, 65px 5px 0 black, 70px 5px 0 black, 75px 5px 0 black, 80px 5px 0 black, 85px 5px 0 black, 90px 5px 0 black, 110px 5px 0 black, 115px 5px 0 black, 120px 5px 0 black, 125px 5px 0 black, 130px 5px 0 black, 135px 5px 0 black, 175px 5px 0 black, 180px 5px 0 black, 185px 5px 0 black, 190px 5px 0 black, 195px 5px 0 black, 200px 5px 0 black, 5px 15px 0 black, 10px 15px 0 black, 15px 15px 0 black, 20px 15px 0 black, 25px 15px 0 black, 30px 15px 0 black, 35px 15px 0 black, 45px 15px 0 black, 50px 15px 0 black, 55px 15px 0 black, 60px 15px 0 black, 65px 15px 0 black, 70px 15px 0 black, 75px 15px 0 black, 80px 15px 0 black, 85px 15px 0 black, 90px 15px 0 black, 95px 15px 0 black, 100px 15px 0 black, 110px 15px 0 black, 115px 15px 0 black, 120px 15px 0 black, 125px 15px 0 black, 130px 15px 0 black, 135px 15px 0 black, 140px 15px 0 black, 170px 15px 0 black, 175px 15px 0 black, 180px 15px 0 black, 185px 15px 0 black, 190px 15px 0 black, 195px 15px 0 black, 200px 15px 0 black, 15px 25px 0 black, 20px 25px 0 black, 25px 25px 0 black, 55px 25px 0 black, 60px 25px 0 black, 65px 25px 0 black, 90px 25px 0 black, 95px 25px 0 black, 100px 25px 0 black, 120px 25px 0 black, 125px 25px 0 black, 130px 25px 0 black, 135px 25px 0 black, 140px 25px 0 black, 145px 25px 0 black, 170px 25px 0 black, 175px 25px 0 black, 180px 25px 0 black, 185px 25px 0 black, 190px 25px 0 black, 15px 35px 0 black, 20px 35px 0 black, 25px 35px 0 black, 55px 35px 0 black, 60px 35px 0 black, 65px 35px 0 black, 70px 35px 0 black, 75px 35px 0 black, 80px 35px 0 black, 85px 35px 0 black, 90px 35px 0 black, 95px 35px 0 black, 120px 35px 0 black, 125px 35px 0 black, 130px 35px 0 black, 135px 35px 0 black, 140px 35px 0 black, 145px 35px 0 black, 150px 35px 0 black, 160px 35px 0 black, 165px 35px 0 black, 170px 35px 0 black, 175px 35px 0 black, 180px 35px 0 black, 185px 35px 0 black, 190px 35px 0 black, 15px 45px 0 black, 20px 45px 0 black, 25px 45px 0 black, 55px 45px 0 black, 60px 45px 0 black, 65px 45px 0 black, 70px 45px 0 black, 75px 45px 0 black, 80px 45px 0 black, 85px 45px 0 black, 90px 45px 0 black, 95px 45px 0 black, 120px 45px 0 black, 125px 45px 0 black, 130px 45px 0 black, 140px 45px 0 black, 145px 45px 0 black, 150px 45px 0 black, 155px 45px 0 black, 160px 45px 0 black, 165px 45px 0 black, 170px 45px 0 black, 180px 45px 0 black, 185px 45px 0 black, 190px 45px 0 black, 15px 55px 0 black, 20px 55px 0 black, 25px 55px 0 black, 55px 55px 0 black, 60px 55px 0 black, 65px 55px 0 black, 90px 55px 0 black, 95px 55px 0 black, 100px 55px 0 black, 120px 55px 0 black, 125px 55px 0 black, 130px 55px 0 black, 145px 55px 0 black, 150px 55px 0 black, 155px 55px 0 black, 160px 55px 0 black, 165px 55px 0 black, 180px 55px 0 black, 185px 55px 0 black, 190px 55px 0 black, 5px 65px 0 black, 10px 65px 0 black, 15px 65px 0 black, 20px 65px 0 black, 25px 65px 0 black, 30px 65px 0 black, 35px 65px 0 black, 45px 65px 0 black, 50px 65px 0 black, 55px 65px 0 black, 60px 65px 0 black, 65px 65px 0 black, 70px 65px 0 black, 75px 65px 0 black, 80px 65px 0 black, 85px 65px 0 black, 90px 65px 0 black, 95px 65px 0 black, 100px 65px 0 black, 110px 65px 0 black, 115px 65px 0 black, 120px 65px 0 black, 125px 65px 0 black, 130px 65px 0 black, 150px 65px 0 black, 155px 65px 0 black, 160px 65px 0 black, 180px 65px 0 black, 185px 65px 0 black, 190px 65px 0 black, 195px 65px 0 black, 200px 65px 0 black, 5px 75px 0 black, 10px 75px 0 black, 15px 75px 0 black, 20px 75px 0 black, 25px 75px 0 black, 30px 75px 0 black, 35px 75px 0 black, 45px 75px 0 black, 50px 75px 0 black, 55px 75px 0 black, 60px 75px 0 black, 65px 75px 0 black, 70px 75px 0 black, 75px 75px 0 black, 80px 75px 0 black, 85px 75px 0 black, 90px 75px 0 black, 110px 75px 0 black, 115px 75px 0 black, 120px 75px 0 black, 125px 75px 0 black, 130px 75px 0 black, 155px 75px 0 black, 180px 75px 0 black, 185px 75px 0 black, 190px 75px 0 black, 195px 75px 0 black, 200px 75px 0 black;
}
