@import "toolkit";


/**
  * Intrinsic Ratio Parent
**/
.ir {
  // Parent
  &--parent-default {
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio-parent;";
    @include intrinsic-ratio-parent;
  }
  &--parent-extend {
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio-parent(true);";
    @include intrinsic-ratio-parent(true);
  }
}

/**
  * Intrinsic Ratio Child
**/
.ir {
  // Child
  &--child-default {
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio-child;";
    @include intrinsic-ratio-child;
  }
  &--child-extend {
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio-child(true);";
    @include intrinsic-ratio-child(true);
  }
}

/**
  * Intrinsic Ratio Ratio
**/
.ir {
  // Ratio
  &--ratio-default {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include intrinsic-ratio-ratio;";
    @include intrinsic-ratio-ratio;
  }
  &--ratio-ratio {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include intrinsic-ratio-ratio($ratio: 4/3);";
    @include intrinsic-ratio-ratio($ratio: 4/3);
  }
  &--ratio-width {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include intrinsic-ratio-ratio($width: 75%);";
    @include intrinsic-ratio-ratio($width: 75%);
  }
  &--ratio-position {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include intrinsic-ratio-ratio($position: bottom);";
    @include intrinsic-ratio-ratio($position: bottom);
  }

  &--ir-ratio-default {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include ir-ratio;";
    @include ir-ratio;
  }
  &--ir-ratio-ratio {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include ir-ratio($ratio: 4/3);";
    @include ir-ratio($ratio: 4/3);
  }
  &--ir-ratio-width {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include ir-ratio($width: 75%);";
    @include ir-ratio($width: 75%);
  }
  &--ir-ratio-position {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _test: "@include ir-ratio($position: bottom);";
    @include ir-ratio($position: bottom);
  }
}

/**
  * Full IR Mixin
**/
.ir {
  // Full
  &--full-default {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio;";
    @include intrinsic-ratio;
  }
  &--full-ratio {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio($ratio: 4/3);";
    @include intrinsic-ratio($ratio: 4/3);
  }
  &--full-width {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio($width: 75%);";
    @include intrinsic-ratio($width: 75%);
  }
  &--full-position {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio($position: bottom);";
    @include intrinsic-ratio($position: bottom);
  }
  &--full-elements {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio($width: 75%);";
    @include intrinsic-ratio($elements: "iframe");
  }
  &--full-extend {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include intrinsic-ratio($position: bottom);";
    @include intrinsic-ratio($extend: true);
  }
}

/**
  * Full IR Mixin (short name)
**/
.ir {
  &--ir-default {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir;";
    @include ir;
  }
  &--ir-ratio {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir($ratio: 4/3);";
    @include ir($ratio: 4/3);
  }
  &--ir-width {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir($width: 75%);";
    @include ir($width: 75%);
  }
  &--ir-position {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir($position: bottom);";
    @include ir($position: bottom);
  }
  &--ir-elements {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir($width: 75%);";
    @include ir($elements: "iframe");
  }
  &--ir-extend {
    _setting-intrinsic-ratio: toolkit-get('intrinsic ratio');
    _setting-intrinsic-ratio-width: toolkit-get('intrinsic ratio width');
    _setting-intrinsic-ratio-direction: toolkit-get('intrinsic ratio position');
    _setting-intrinsic-ratio-elements: toolkit-get('intrinsic ratio elements');
    _setting-intrinsic-ratio-extend: toolkit-get('intrinsic ratio extend');
    _test: "@include ir($position: bottom);";
    @include ir($extend: true);
  }
}