/**
  * RTL
**/
.rtl--single-without {
  _test: "@include rtl(padding, 1.5em);";
  padding: 1.5em;
}
.rtl--single-right {
  _test: "@include rtl(padding-right, 1.5em);";
  padding-right: 1.5em;
}
[dir="rtl"] .rtl--single-right {
  padding-left: 1.5em;
}
.rtl--single-left {
  _test: "@include rtl(padding-left, 1.5em);";
  padding-left: 1.5em;
}
[dir="rtl"] .rtl--single-left {
  padding-right: 1.5em;
}
.rtl--double {
  _test: "@include rtl(padding, 1.5em 2.5em);";
  padding: 1.5em 2.5em;
}
.rtl--tripple {
  _test: "@include rtl(padding, 1.5em 2.5em 3.5em);";
  padding: 1.5em 2.5em 3.5em;
}
.rtl--quadruple {
  _test: "@include rtl(padding, 1.5em 2.5em 3.5em 4.5em);";
  padding: 1.5em 2.5em 3.5em 4.5em;
}
[dir="rtl"] .rtl--quadruple {
  padding: 1.5em 4.5em 3.5em 2.5em;
}
