/*! Reset/normalize hybrid with major contributions from normalize.css, html5doctor.com Reset Stylesheet, and http://html5reset.org/

* Sam Richard - http://snugug.com/
* Nicholas Gallagher, Jonathan Neal - http://necolas.github.io/normalize.css/
* Richard Clark - http://richclarkdesign.com
* Tim Murtaugh - http://monkeydo.biz/
*/

//////////////////////////////
// Basic reset
//////////////////////////////
abbr,
address,
article,
aside,
audio,
b,
blockquote,
body,
canvas,
caption,
cite,
code,
dd,
del,
details,
dfn,
div,
dl,
dt,
em,
fieldset,
figcaption,
figure,
footer,
form,
h1,
h2,
h3,
h4,
h5,
h6,
header,
hgroup,
html,
i,
iframe,
img,
ins,
kbd,
label,
legend,
li,
mark,
main,
menu,
nav,
object,
ol,
p,
pre,
q,
samp,
section,
small,
span,
strong,
sub,
summary,
sup,
table,
tbody,
td,
tfoot,
th,
thead,
time,
tr,
ul,
var,
video {
  background: transparent;
  border: 0;
  font-size: 100%;
  margin: 0;
  outline: 0;
  padding: 0;
  vertical-align: baseline;
}

//////////////////////////////
// Prevent iOS text size adjust after orientation change, without disabling user zoom.
//////////////////////////////

html {
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}

//////////////////////////////
// Resets body line height
//////////////////////////////

body {
  line-height: 1;
}

//////////////////////////////////////////////////////////////////////////
// HTML5 display definitions
//////////////////////////////////////////////////////////////////////////


//////////////////////////////
// Correct `block` display not defined for any HTML5 element in IE 8/9.
// Correct `block` display not defined for `details` or `summary` in IE 10/11 and Firefox.
// Correct `block` display not defined for `main` in IE 11.
//////////////////////////////

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block;
}

//////////////////////////////
// 1. Correct `inline-block` display not defined in IE 8/9.
// 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
//////////////////////////////

audio,
canvas,
progress,
video {
  display: inline-block; // 1
  vertical-align: baseline; // 2
}

//////////////////////////////
// Prevent modern browsers from displaying `audio` without controls.
// Remove excess height in iOS 5 devices.
//////////////////////////////

audio:not([controls]) {
  display: none;
  height: 0;
}

//////////////////////////////
// Address `[hidden]` styling not present in IE 8/9/10.
// Hide the `template` element in IE 8/9/11, Safari, and Firefox < 22.
//////////////////////////////

[hidden],
template {
  display: none;
}

//////////////////////////////////////////////////////////////////////////
// Links
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// Remove the gray background color from active links in IE 10.
//////////////////////////////

a {
  background-color: transparent;
  font-size: 100%;
  margin: 0;
  padding: 0;
  vertical-align: baseline;
}

//////////////////////////////
// Improve readability when focused and also mouse hovered in all browsers.
//////////////////////////////

a:active,
a:hover {
  outline: 0;
}

//////////////////////////////////////////////////////////////////////////
// Text-level semantics
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// Address styling not present in IE 8/9/10/11, Safari, and Chrome.
//////////////////////////////

abbr[title],
dfn[title] {
  border-bottom: 1px dotted;
  cursor: help;
}

//////////////////////////////
// Remove text decoration
//////////////////////////////

ins {
  text-decoration: none;
}

//////////////////////////////
// Adds strikethrough
//////////////////////////////
del {
  text-decoration: line-through;
}

//////////////////////////////
// Reset quotes for blockquote
//////////////////////////////

blockquote,
q {
  quotes: none;
}

blockquote:before,
blockquote:after,
q:before,
q:after {
  content: '';
  content: none;
}

//////////////////////////////
// Remove list style for lists
//////////////////////////////
ul {
  list-style: none;
}

//////////////////////////////////////////////////////////////////////////
// Embedded content
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// Remove border when inside `a` element in IE 8/9/10.
//////////////////////////////
img {
  border: 0;
}

//////////////////////////////
// Correct overflow not hidden in IE 9/10/11.
//////////////////////////////

svg:not(:root) {
  overflow: hidden;
}

//////////////////////////////////////////////////////////////////////////
// Grouping content
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// 1. Contain overflow in all browsers.
// 2. Pre-format text
//////////////////////////////

pre {
  overflow: auto; // 1
  white-space: pre; // 2
  white-space: pre-wrap; // 2
  white-space: pre-line; // 2
  word-wrap: break-word; // 2
}

//////////////////////////////
// 1. Address odd `em`-unit font size rendering in all browsers.
// 2. Ensure monospace font
//////////////////////////////

code,
kbd,
pre,
samp {
  font-size: 1em; // 1
  font-family: monospace, sans-serif;
}

//////////////////////////////
// Address differences between Firefox and other browsers
//////////////////////////////

hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid;
  margin: 1em 0;
  padding: 0;
}

//////////////////////////////////////////////////////////////////////////
// Forms
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// Known limitation: by default, Chrome and Safari on OS X allow very limited styling of `select`, unless a `border` property is set.
//////////////////////////////

//////////////////////////////
// 1. Correct color not being inherited.
//    Known issue: affects color of disabled elements.
// 2. Correct font properties not being inherited.
// 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
//////////////////////////////

button,
input,
optgroup,
select,
textarea {
  color: inherit; // 1
  font: inherit; // 2
  margin: 0; // 3
}

//////////////////////////////
// Address `overflow` set to `hidden` in IE 8/9/10/11.
//////////////////////////////

button,
input[type="button"] {
  overflow: visible;
}

//////////////////////////////
// Address inconsistent `text-transform` inheritance for `button` and `select`.
// All other form control elements do not inherit `text-transform` values.
// Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
// Correct `select` style inheritance in Firefox.
//////////////////////////////

button,
select {
  text-transform: none;
}

//////////////////////////////
// 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio` and `video` controls.
// 2. Correct inability to style clickable `input` types in iOS.
// 3. Improve usability and consistency of cursor style between image-type `input` and others.
//////////////////////////////

button,
html input[type="button"], // 1
input[type="file"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button; // 2
  cursor: pointer; // 3
}

//////////////////////////////
// Re-set default cursor for disabled elements.
//////////////////////////////

button[disabled],
html input[disabled] {
  cursor: default;
}

//////////////////////////////
// Remove inner padding and border in Firefox 4+.
//////////////////////////////

button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

//////////////////////////////
// Address Firefox 4+ setting `line-height` on `input` using `!important` in the UA stylesheet.
//////////////////////////////

input {
  line-height: normal;
}

//////////////////////////////
// It's recommended that you don't attempt to style these elements.
// Firefox's implementation doesn't respect box-sizing, padding, or width.
//
// Removes excess padding in IE 8/9/10.
//////////////////////////////

input[type="checkbox"],
input[type="radio"] {
  padding: 0;
}

//////////////////////////////
// Fix the cursor style for Chrome's increment/decrement buttons. For certain `font-size` values of the `input`, it causes the cursor style of the decrement button to change from `default` to `text`.
//////////////////////////////

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

//////////////////////////////
// Remove inner padding and search cancel button in Safari and Chrome on OS X.
// Safari (but not Chrome) clips the cancel button when the search input has padding (and `textfield` appearance).
//////////////////////////////

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

//////////////////////////////
// 1. Correct `color` not being inherited in IE 8/9/10/11.
// 2. Remove padding so people aren't caught out if they zero out fieldsets.
//////////////////////////////

legend {
  border: 0; // 1
  padding: 0; // 2
}

//////////////////////////////
// Remove default vertical scrollbar in IE 8/9/10/11.
//////////////////////////////

textarea {
  overflow: auto;
}

//////////////////////////////
// Align input and select text
//////////////////////////////

input,
select {
  vertical-align:middle;
}

//////////////////////////////////////////////////////////////////////////
// Tables
//////////////////////////////////////////////////////////////////////////

//////////////////////////////
// Remove most spacing between table cells.
//////////////////////////////

table {
  border-collapse: collapse;
  border-spacing: 0;
}

//////////////////////////////
// Remove padding from table cell and table header
//////////////////////////////

td,
th {
  padding: 0;
}

//////////////////////////////////////////////////////////////////////////
// Kickstart
//////////////////////////////////////////////////////////////////////////

@import "kickstart";
