@import "center";
@warn "DEPRECATION: Vertical Center has been moved to the `center` partial, please change your import from `toolkit/vertical-center` to `toolkit/center`. In a future release, this will be deprecated.";