/**
  * Ligatures
**/
.ligatures--no-extend {
  _setting-extend-ligatures: false;
  _test: "@include enable-ligatures(false)";
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
}
.ligatures--extend {
  _setting-extend-ligatures: false;
  _test: "@include enable-ligatures(true)";
}
.ligatures--extend, .ligatures--default-change {
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
}
.ligatures--default {
  _setting-extend-ligatures: false;
  _test: "@include enable-ligatures";
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
}
.ligatures--default-change {
  _setting-extend-ligatures: true;
  _test: "@include enable-ligatures";
}

/**
  * Font Face
**/
.font-face {
  _fonts: ("eot": "north/north.eot", "woff": "north/north.woff", "svg": "north/north.svg");
  _test: "@include font-face('north', $fonts, $inline-woff: true);";
}

@font-face {
  font-family: "north";
  font-weight: normal;
  font-style: normal;
  src: url('../fonts/north/north.eot') format("embedded-opentype");
  src: url('../fonts/north/north.eot#iefix') format("embedded-opentype"), url('data:application/font-woff;base64,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') format('woff'), url('../fonts/north/north.svg') format("svg");
}
/**
  * Icon Font
**/
.icon-font--no-extend {
  _setting-speak-icon-font: false;
  _setting-extend-icon-font: false;
  _test: "@include icon-font('north', $extend: false);";
  font-family: "north";
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.icon-font--speak {
  _setting-speak-icon-font: false;
  _setting-extend-icon-font: false;
  _test: "@include icon-font('north', true);";
  font-family: "north";
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.icon-font--extend {
  _setting-speak-icon-font: false;
  _setting-extend-icon-font: false;
  _test: "@include icon-font('north', $extend: true);";
  font-family: "north";
  speak: none;
}
.icon-font--extend {
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-feature-settings: "liga","dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga","dlig";
  -ms-font-feature-settings: "liga","dlig";
  -o-font-feature-settings: "liga","dlig";
  font-feature-settings: "liga","dlig";
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

/**
  * Content Fade In
**/
.content-fade-in--default {
  _setting-fade-in-duration: 1s;
  _settin-fade-in-loading-class: ".wf-loading";
  _setting-fade-in-extend: false;
  _test: "@include content-fade-in();";
  opacity: 1;
  -webkit-transition: opacity 1s;
  transition: opacity 1s;
}
.wf-loading .content-fade-in--default {
  opacity: 0;
}
.content-fade-in--extend {
  _setting-fade-in-duration: 1s;
  _settin-fade-in-loading-class: ".wf-loading";
  _setting-fade-in-extend: false;
  _test: "@include content-fade-in($extend: true);";
}
.content-fade-in--extend {
  opacity: 1;
  -webkit-transition: opacity 1s;
  transition: opacity 1s;
}
.wf-loading .content-fade-in--extend {
  opacity: 0;
}
