@import "toolkit";

/**
  * RTL
**/
.rtl {
  &--single-without {
    _test: "@include rtl(padding, 1.5em);";
    @include rtl(padding, 1.5em);
  }
  &--single-right {
    _test: "@include rtl(padding-right, 1.5em);";
    @include rtl(padding-right, 1.5em);
  }
  &--single-left {
    _test: "@include rtl(padding-left, 1.5em);";
    @include rtl(padding-left, 1.5em);
  }
  &--double {
    _test: "@include rtl(padding, 1.5em 2.5em);";
    @include rtl(padding, 1.5em 2.5em);
  }
  &--tripple {
    _test: "@include rtl(padding, 1.5em 2.5em 3.5em);";
    @include rtl(padding, 1.5em 2.5em 3.5em);
  }
  &--quadruple {
    _test: "@include rtl(padding, 1.5em 2.5em 3.5em 4.5em);";
    @include rtl(padding, 1.5em 2.5em 3.5em 4.5em);
  }
}